==> schema-language-server-8.579.17.jar: hover/services/container/document-processing/document-processing.md <==
## document-processing

The root element of the *document-processing* configuration model.

|        Attribute        | Required | Value | Default |                                                                                                                                                    Description                                                                                                                                                     |
|-------------------------|----------|-------|---------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| numnodesperclient       | optional |       |         | <br /> **Deprecated:** Ignored and deprecated, will be removed in Vespa 9. Set to some number below the amount of nodes in the cluster to limit how many nodes a single client can connect to. If you have ++many++ clients, this can reduce the memory usage on both document-processing and client nodes. <br /> |
| preferlocalnode         | optional |       | false   | <br /> **Deprecated:** Ignored and deprecated, will be removed in Vespa 9. Set to always prefer sending to a document-processing node running on the same host as the client. You should use this if you are running a client on each document-processing node. <br />                                             |
| maxmessagesinqueue      |          |       |         | <br />                                                                                                                                                                                                                                                                                                             |
| maxqueuebytesize        |          |       |         | <br /> **Deprecated:** Ignored and deprecated, will be removed in Vespa 9. <br />                                                                                                                                                                                                                                  |
| maxqueuewait            | optional |       |         | The maximum number of seconds a message should wait in queue before being processed. Docproc will adapt its queue size to adhere to this. If the queue is full, new messages will be replied to with SESSION_BUSY.                                                                                                 |
| maxconcurrentfactor     |          |       |         | <br />                                                                                                                                                                                                                                                                                                             |
| documentexpansionfactor | optional |       |         | <br />                                                                                                                                                                                                                                                                                                             |
| containercorememory     |          |       |         | <br />                                                                                                                                                                                                                                                                                                             |

[Read more](https://docs.vespa.ai/en/reference/services-docproc.html#)

==> schema-language-server-8.626.55.jar: hover/services/container/document-processing/document-processing.md <==
## document-processing

The root element of the *document-processing* configuration model.

|        Attribute        | Required | Value | Default |                                                                                                                                                    Description                                                                                                                                                     |
|-------------------------|----------|-------|---------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| numnodesperclient       | optional |       |         | <br /> **Deprecated:** Ignored and deprecated, will be removed in Vespa 9. Set to some number below the amount of nodes in the cluster to limit how many nodes a single client can connect to. If you have ++many++ clients, this can reduce the memory usage on both document-processing and client nodes. <br /> |
| preferlocalnode         | optional |       | false   | <br /> **Deprecated:** Ignored and deprecated, will be removed in Vespa 9. Set to always prefer sending to a document-processing node running on the same host as the client. You should use this if you are running a client on each document-processing node. <br />                                             |
| maxmessagesinqueue      |          |       |         | <br />                                                                                                                                                                                                                                                                                                             |
| maxqueuebytesize        |          |       |         | <br /> **Deprecated:** Ignored and deprecated, will be removed in Vespa 9. <br />                                                                                                                                                                                                                                  |
| maxqueuewait            | optional |       |         | The maximum number of seconds a message should wait in queue before being processed. Docproc will adapt its queue size to adhere to this. If the queue is full, new messages will be replied to with SESSION_BUSY.                                                                                                 |
| maxconcurrentfactor     |          |       |         | <br />                                                                                                                                                                                                                                                                                                             |
| documentexpansionfactor | optional |       |         | <br />                                                                                                                                                                                                                                                                                                             |
| containercorememory     |          |       |         | <br />                                                                                                                                                                                                                                                                                                             |

[Read more](https://docs.vespa.ai/en/reference/applications/services/docproc.html#)
